use "${procdata}merge_total_elegibles.dta", clear

*Sex
rename sexo sex
replace sex=0 if sex==1
replace sex=1 if sex==2
label define label_sex 0 "Male" 1 "Female" 
label values sex label_sex 

*Intersex
gen intersex = .
replace intersex=1 if p7_1a==1
replace intersex=0 if p7_1a==2
label define label_inter 0 "No" 1 "Yes"
label values intersex label_inter
label variable intersex "Intersex"

gen inters = .
replace inters =1 if p7_1a==1
replace inters =2 if p7_1a==2
replace inters =3 if p7_1a==3
replace inters =4 if p7_1a==9
label define label_inters 1 "Yes" 2 "No" 3 "Don't understand" 4 "Not specified"
label values inters label_inters
label variable inters "Intersex"

*Age
rename edad age
replace age=. if age==98
label variable age "Age"

*Age2
gen age2=age*age
label variable age2 "Age squared"

*Afro
rename p4_4 afro
label variable afro "Afro-descendant"
replace afro=0 if afro==2
label define label_ys 0 "No" 1 "Yes"
label values afro label_ys

*Indigenous
gen indig=0
replace indig=1 if p4_6==1
replace indig=1 if p4_6==2 & (p4_8==1 | p4_8==2 )
label variable indig "Indigenous"
label values indig label_ys

*Marital status
gen partner=0
replace partner=1 if p4_2==1 | p4_2==2
label variable partner "Partner"
label value partner label_yn

gen single=0
replace single=1 if p4_2==6
label variable single "Single"
label value single label_yn

gen sep=0
replace sep=1 if p4_2==3 | p4_2==4 | p4_2==5
label variable sep "Separated"
label value sep label_yn

*Education
gen less_sec=0
replace less_sec=1 if niv==0 | niv==1 | niv==2 | niv==3 //less than secondary
label variable less_sec "Less than secondary"
label value less_sec label_yn

gen sec=0
replace sec=1 if niv==4 | niv==5 | niv==6 
label variable sec "Secondary"
label value sec label_yn

gen post_sec=0
replace post_sec=1 if niv==7 | niv==8 | niv==9 | niv==10 
label variable post_sec "Post secondary"
label value post_sec label_yn

*Skin tone
rename p4_19 skin_tone
label variable skin_tone "Skin tone"
replace skin_tone=. if skin_tone==99
*State
label variable ent "State"


*Labor Force Participation (LFP)
gen lfp =.
replace lfp = 1 if p4_13==1 
replace lfp = 2 if p4_13==2 //==valores
replace lfp = 3 if p4_13==3 & p4_14==6 
replace lfp = 1 if p4_13==3 & inrange(p4_14,1,5)
replace lfp = 4 if p4_13==4 & p4_14==6 
replace lfp = 1 if p4_13==4 & inrange(p4_14,1,5)
replace lfp = 5 if p4_13==5 & p4_14==6 
replace lfp = 1 if p4_13==5 & inrange(p4_14,1,5)
replace lfp = 6 if p4_13==6 & p4_14==6 
replace lfp = 1 if p4_13==6 & inrange(p4_14,1,5)
replace lfp = 7 if p4_13==7 
replace lfp = 1 if p4_13==8 & inrange(p4_14,1,5)
replace lfp = 8 if p4_13==8 & p4_14==6 
recode lfp (1/3=1) (4/8=0)
label variable lfp "Labor force participation"
label values lfp label_yn

*Unemployment
gen unemp=.
replace unemp=0 if lfp==1
replace unemp = 1 if p4_13==3 & lfp==1
label variable unemp "Unemployed"
label values unemp label_yn

*Sexual Orientation
gen orientation=0 if  p8_1==4  | p8_1==5
replace orientation=1 if p8_1a==3
replace orientation=2 if (p8_1a==1 | p8_1a==2)
replace orientation=3 if p8_1a==4
label define label_os 0 "Heterosexual" 1 "Bisexual" 2 "Gay/Lesbian" 3 "Other"
label values orientation label_os
label variable orientation "Sexual Orientation"

gen sex_or=0 if orientation==0
replace sex_or=1 if orientation>0
label define label_so 0 "Heterosexual" 1 "LGB+"
label values sex_or label_so
label variable sex_or "Sexual Orientation"

gen trans_dist=1 if p9_1==1
replace trans_dist=2 if p9_1==2
replace trans_dist=3 if p9_1==3
replace trans_dist=4 if p9_1==4
replace trans_dist=5 if p9_1==5
label define label_td 1 "Male" 2 "Female" 3 "Both male and female" 4 "Neither male nor female" 5 "Other gender"
label values trans_dist label_td
label variable trans_dist "Trans+"

*Gender Identity
gen identity=0 if p9_1==1 & sex==0
replace identity=0 if p9_1==2 & sex==1
replace identity=1 if p9_1==1 & sex==1 
replace identity=1 if p9_1==2 & sex==0 
replace identity=1 if p9_1==3
replace identity=1 if p9_1==4
replace identity=1 if p9_1==5
label variable identity "Gender Identity"
label define label_iden 0 "Cisgender" 1 "Trans+" 
label values identity label_iden


********************
**Dummies for SOGI**
********************
gen hetero=0
replace hetero=1 if orientation==0
label variable hetero "Heterosexual"
gen bi=0
replace bi=1 if orientation==1
label variable bi "Bisexual"
gen gayles=0
replace gayles=1 if orientation==2
label variable gayles "Gay/Lesbian"
gen other=0
replace other=1 if orientation==3
label variable other "Other"
gen cis=0
replace cis=1 if identity==0
label variable cis "Cisgender"
gen trans=0
replace trans=1 if identity==1
label variable trans "Trans+"

*LGBTQ total
gen LGBTQ=0
replace LGBTQ=1 if orientation==1 | orientation==2 | orientation==3 
replace LGBTQ=1 if identity==1 & orientation==0
label variable LGBTQ "LGBTQ+"
label define label_lgbtq 1 "LGBTQ" 0 "No" 
label values LGBTQ label_lgbtq


****************
*Discrimination
****************
recode p8_5 (1=1) (2=0) (9=.) (.=0), gen(sex_disc)
tab sex_disc 
label variable sex_disc "Sexual Orientation discrimination"
label values sex_disc label_ys


gen gen_disc=0 if p11_6_08==2
replace gen_disc=1 if p11_6_08==1
label variable gen_disc "Gender discrimination"
label values gen_disc label_ys

*Rejection at work
gen work=0
replace work=. if p11_4_1==. & p11_4_2==. & p11_4_3==. & p11_4_4==. & p11_4_5==.
replace work=1 if p11_4_1==1 | p11_4_2==1 | p11_4_3==1 |p11_4_4==1 |p11_4_5==1 
label variable work "Rejection at work"

rename num_menores15 under15

rename num_miembros hsize

egen children = anycount(under15), values(1/11) 
label variable children "Child at home"


****************
*Mental Health
****************
forvalues i=1/5 {
	recode p10_1_`i' (1=1) (2=0)
	label values p10_1_`i' label_ys 
}

gen mental_health = p10_1_1 + p10_1_2 + p10_1_3 + p10_1_4 + p10_1_5 
label variable mental_health "Mental Health"
*In the last 12 months, from August 2020 to date, have you had...
label variable p10_1_1 "insomnia"
label variable p10_1_2 "stress"
label variable p10_1_3 "depression"
label variable p10_1_4 "loss or increase in appetite or weigh"
label variable p10_1_5 "anguish, fear or anxiety?"

gen suic_idea=0 if p10_2==2
replace suic_idea=1 if p10_2==1
label variable suic_idea "Suicidal Ideation"
label values suic_idea label_ys 


gen suic_inten=0 if p10_3==2
replace suic_inten=1 if p10_3==1
label variable suic_inten "Suicidal Intention"
label values suic_inten label_ys 

forvalues i=1/6 {
	recode p11_1_`i' (1=1) (2=0)
	label values p11_1_`i' label_ys 
}

forvalues i=1/8 {
	recode p10_4_`i' (1=1) (2=0) (9=.)
	label values p10_4_`i' label_ys 
}
*10.4 Was this mainly due to...?
label variable p10_4_1 "financial problems"
label variable p10_4_2 "family or relationship problems"
label variable p10_4_3 "health problems"
label variable p10_4_4 "problems at school"
label variable p10_4_5 "problems at work"
*APPLY OPTION 6 ONLY IF SEXUAL ORIENTATION (8.1) IS CODE 1,2,3 OR 6.
label variable p10_4_6 "problems because of your orientation"
*APPLY OPTION 7 ONLY IF SEX AT BIRTH OTHER THAN GENDER IDENTITY (7.1 ≠ 9.1).
label variable p10_4_7 "problems due to your gender"
label variable p10_4_8 "other"


****************
*Sexual Health
****************
label variable p11_1_1 "Have you been threatened or sexually assaulted?"
label variable p11_1_2 "Have you been bothered by someone making sexual propositions in exchange for payment?"
label variable p11_1_3 "Have you been forced to have sexual relations?"
label variable p11_1_4 "Have you been humiliated, embarrassed, or verbally abused?"
label variable p11_1_5 "Have you received offensive messages?"
label variable p11_1_6 "Have you been touched or groped without your consent?"

recode p11_5_1 (1=1) (2=0) (3=.) (9=.)
label values p11_5_1 label_suic 
label variable p11_5_1 "Have you been unjustifiably denied medical attention or medication?"

*Childhood
forvalues i=1/4 {
	recode p5_3_`i' (1=1) (2=0)
	label values p5_3_`i' label_ys 
}

*During your childhood (up to 11 years old), did you ever feel different from most other girls or boys your age because of...
label variable p5_3_1 "your way of dressing or grooming?" 
label variable p5_3_2 "your tastes or interests?"
label variable p5_3_3 "your way of speaking or expressing yourself?"
label variable p5_3_4 "your manners or way of behaving?"

forvalues i=1/5 {
	recode p5_4_`i' (1=1) (2=0)
	label values p5_4_`i' label_ys 
}

*During your childhood (up to 11 years old), for bothering you or making you feel bad, did anyone ever...
label variable p5_4_1 "reject or exclude you from social activities?"
label variable p5_4_2 "insult you, mock you, or say things that offended you?"
label variable p5_4_3 "steal, hide, or break your belongings?"
label variable p5_4_4 "threaten or blackmail you?"
label variable p5_4_5 "push, pull, or hit you?"


*12 to present
forvalues i=1/4 {
	recode p6_10_`i' (1=1) (2=0)
	label values p6_10_`i' label_ys 
	recode p6_4_`i' (1=1) (2=0)
	label values p6_4_`i' label_ys	
	replace p6_10_`i'= p6_4_`i' if p6_10_`i'==.
}

*p10 Have you ever been made to feel different from most other girls or boys because of...
label variable p6_10_1 "your way of dressing or grooming?"
label variable p6_10_2 "your tastes or interests?"
label variable p6_10_3 "your way of speaking or expressing yourself?"
label variable p6_10_4 "your manners or way of behaving?"

forvalues i=1/5 {
	recode p6_11_`i' (1=1) (2=0)
	label values p6_11_`i' label_ys 
	recode p6_5_`i' (1=1) (2=0)
	label values p6_5_`i' label_ys 
	replace p6_11_`i'=p6_5_`i' if p6_11_`i'==.
}

*6.11 From age 12 to the present, have you been bothered or made to feel bad...
label variable p6_11_1 "Have you been rejected or excluded from social activities?"
label variable p6_11_2 "Have you been insulted, mocked, or told things that offend you?"
label variable p6_11_3 "Have your belongings been stolen, hidden, or broken?"
label variable p6_11_4 "Have you been threatened or blackmailed?"
label variable p6_11_5 "Have you been pushed, pulled, or hit?"
 
replace p7_3=. if p7_3==98 | p7_3==99
gen sexual_enc=1 if p7_3==0
replace sexual_enc=0 if p7_3>0
label variable sexual_enc "People who have never had their first meeting with someone where there was kissing or cuddling and they agreed"

replace p7_5=. if p7_5==98 | p7_5==99
gen sexual_relation=1 if p7_5==0
replace sexual_relation=0 if p7_5>0
label variable sexual_relation "People who have never had their first sexual relationship"

replace p11_5_5=. if p11_5_5==9 | p11_5_5==3
gen bath_access=1 if p11_5_5==1
replace bath_access=0 if p11_5_5==2
label values bath_access label_ys 
label variable bath_access "You have been unjustifiably denied access to public bathrooms"
tab bath_access
*work rejection
forvalues i=1/5 {
	recode p11_4_`i' (1=1) (2=0) (3=.)
	label values p11_4_`i' label_ys 
}
*During the last 12 months, from August 2020 to the present date, at work...
label variable p11_4_1 "Did you receive offensive comments or teasing?"
label variable p11_4_2 "Were you excluded from events or social activities?"
label variable p11_4_3 "Were you bothered or harassed?"
label variable p11_4_4 "Did you receive unequal treatment regarding benefits, labor benefits, or promotions?"
label variable p11_4_5 "Were you hit, assaulted, or threatened?"


recode p11_6_08 (1=1) (2=0) (9=.)
label values p11_6_08 label_ys 

recode p11_6_10 (1=1) (2=0) (9=.)
label values p11_6_10 label_ys 

label define label_l 1 "A lot"

*12.4 How satisfied are you with your...
label variable p12_4_1 "Economic situation?"
label variable p12_4_2 "Job situation?"
label variable p12_4_3 "Family relationship?"
label variable p12_4_4 "Physical appearance?"
label variable p12_4_5 "Personality?"
label variable p12_4_6 "Life in general?"

forvalues i=1/6 {
	recode p12_4_`i' (1=1) (2=0) (3=0) (4=0) (5=.) (9=.)
	label values p12_4_`i' label_l
}
*12.4 How satisfied are you with your...
label variable p12_4_1 "Economic situation?"
label variable p12_4_2 "Job situation?"
label variable p12_4_3 "Family relationship?"
label variable p12_4_4 "Physical appearance?"
label variable p12_4_5 "Personality?"
label variable p12_4_6 "Life in general?"

forvalues i=1/7 {
	recode p12_5_`i' (1=1) (2=0) (3=0) (4=0) (5=.) (9=.)
	label values p12_5_`i' label_l
}

*12.5 Below I am going to read some statements, tell me how much you agree with each one:

label variable p12_5_1 "What I do in my life is worthwhile"
label variable p12_5_2 "I have a purpose or mission in life"
label variable p12_5_3 "I feel good about myself"
label variable p12_5_4 "I am a fortunate person"
label variable p12_5_5 "I am free to decide my own life"
label variable p12_5_6 "I am very satisfied with my life"
label variable p12_5_7 "So far, I have achieved the things that are important to me"

*Aggregated variables
gen child_rej1= (p5_3_1 + p5_3_2 + p5_3_3 + p5_3_4)/4
gen adol_rej1= (p6_10_1 +p6_10_2 +p6_10_3 +p6_10_4)/4
gen child_rej2= (p5_4_1 + p5_4_2 + p5_4_3 + p5_4_4 + p5_4_5)/5 
gen adol_rej2= (p6_11_1 +p6_11_2 +p6_11_3 +p6_11_4 +p6_11_5)/5 
gen harras=(p11_1_1 +p11_1_2 +p11_1_3 +p11_1_4 +p11_1_5 +p11_1_6)/6
gen mental=(p10_1_1+p10_1_2+p10_1_3+p10_1_4+p10_1_5)/5
gen work_rejection=(p11_4_1 +p11_4_2 +p11_4_3 +p11_4_4 +p11_4_5)/5

*Disability
gen walk_disability = 0
replace walk_disability = 1 if pd4_10_1 > 2

gen vision_disability = 0
replace vision_disability = 1 if pd4_10_2 > 2

gen cognition_disability = 0
replace cognition_disability = 1 if pd4_10_4 > 2

gen hearing_disability = 0
replace hearing_disability = 1 if pd4_10_5 > 2
tab pd4_10_5

gen task_disability = 0
replace task_disability = 1 if pd4_10_6 > 2

gen communication_disability = 0
replace communication_disability = 1 if pd4_10_7 > 2

gen any_disability = 0
replace any_disability = 1 if walk_disability==1 | vision_disability==1  | cognition_disability==1 | hearing_disability==1 | task_disability ==1 | communication_disability ==1
label variable any_disability "Disability"
label define et_dis 0 "No" 1 "Yes"

gen age_group=1 if age>=15 & age<=29 
replace age_group=2 if age>=30 & age<=44 
replace age_group=3 if age>=45 
label variable age_group "Age Group"
label define et_edad 1 "15-29" 2 "30-44" 3 "45+"
label values age_group et_edad

keep sex age age2 afro indig partner single sep less_sec sec post_sec ent lfp unemp hetero bi gayles other cis trans orientation identity sex_or trans_dist LGBTQ sex_disc gen_disc work factor hsize children under15 intersex inters skin_tone p10_1_1 p10_1_2 p10_1_3 p10_1_4 p10_1_5 mental_health suic_idea suic_inten p11_1_1 p11_1_2 p11_1_3 p11_1_4 p11_1_5 p11_1_6 p11_5_1 bath_access p5_3_1 p5_3_2 p5_3_3 p5_3_4 p5_4_1 p5_4_2 p5_4_3 p5_4_4 p5_4_5 p6_10_1 p6_10_2 p6_10_3 p6_10_4 p6_11_1 p6_11_2 p6_11_3 p6_11_4 p6_11_5 sexual_relation sexual_enc p11_4_1 p11_4_2 p11_4_3 p11_4_4 p11_4_5 p11_6_08 p11_6_10 p12_4_1 p12_4_2 p12_4_3 p12_4_4 p12_4_5 p12_4_6 p12_5_1 p12_5_2 p12_5_3 p12_5_4 p12_5_5 p12_5_6 p12_5_7 p10_4_1 p10_4_2 p10_4_3 p10_4_4 p10_4_5 p10_4_6 p10_4_7 p10_4_8 child_rej1 adol_rej1 child_rej2 adol_rej2 harras mental work_rejection walk_disability vision_disability cognition_disability hearing_disability task_disability communication_disability any_disability age_group est_dis upm_dis

save "${procdata}data_base.dta", replace
