*Figures
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}rej_exp.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}wellbeing.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}lab_mark_out.png", replace
