*********************************
*Descriptive Statistics (Table 1)
*********************************
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


matrix results_i = J(1, 1, .) 
matrix results_f = J(1, 1, .) 
matrix results_m = J(1, 1, .)
matrix results_0 = J(1, 1, .) 
matrix results_1 = J(1, 1, .)


foreach var in age indig afro skin_tone partner sep sec post_sec hsize children bi gayles other trans  {
    forvalue j=1/3{
		qui svy: mean `var' if inter==`j'
		qui estat sd
		qui return list
			if `j'==1 {
				local b_i = r(mean)[1,1]
				local se_i = r(sd)[1,1]
				matrix results_i = results_i \ (`b_i')
				matrix results_i = results_i \ (`se_i')
				}
			if `j'==2 {
				local b_f = r(mean)[1,1]
				local se_f = r(sd)[1,1] 
				matrix results_f = results_f \ (`b_f')
				matrix results_f = results_f \ (`se_f')
				}
			if `j'==3{
				local b_m = r(mean)[1,1]
				local se_m = r(sd)[1,1] 
				matrix results_m = results_m \ (`b_m')
				matrix results_m = results_m \ (`se_m')
				}	
			}
		
		forvalue i=0/1{
		qui svy: mean `var' if sex==`i' | intersex==1, over(intersex) coeflegend
		matrix results_`i' = results_`i' \_b[c.`var' @1.intersex] - _b[c.`var' @0bn.intersex]

		qui test _b[c.`var'@0bn.intersex]	= _b[c.`var'@1.intersex]
		qui return list
		scalar p_val = r(p) // Store the p-value
		matrix results_`i' = results_`i' \ p_val
	}
}			


mat desc_stat=[results_f, results_m, results_i, results_1, results_0]
mat desc_stat=desc_stat[2...,.]
matrix colnames desc_stat = "Endosex Female" "Endosex Male " "Intersex" "(3)-(1)" "(3)-(2)"
mat li desc_stat, format(%9.2f) 


*******************
*EXCEL
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Sociodemographic", replace) modify
putexcel A1 =("Category")
putexcel B1=("Female") 
putexcel C1 =("Male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Age") 
putexcel A4 =("Indigenous")
putexcel A6 =("African descendant")
putexcel A8 =("Skin tone")
putexcel A10 =("Married or partnered")
putexcel A12 =("Divorced, widowed or separated")
putexcel A14 =("Secondary")
putexcel A16 =("Post secondary")
putexcel A18 =("Household size")
putexcel A20 =("Children at home")
putexcel A22 =("Bisexual")
putexcel A24 =("Gay/Lesbian")
putexcel A26 =("Other")
putexcel A28 =("Trans+")
putexcel A30 =("Observations")

*Matrix to excel
putexcel B2=matrix(desc_stat), nformat(number_d2)


*********************************
*Sample size (Table 2)
*********************************
use "${procdata}data_base.dta", clear
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)
keep if age>=15 & age<=64 //working age people

*Table 2: Sample size, individuals aged 15 – 64 years.
*Observations
*Column 1
tab intersex,  matcell(c1)
scalar f4c1 = c1[1,1]
scalar f1c1 = c1[2,1]

tab sex intersex if intersex==1, matcell(c1_1)
scalar f2c1 = c1_1[1,1]
scalar f3c1 = c1_1[2,1]

tab sex intersex if intersex==0, matcell(c1_2)
scalar f5c1 = c1_2[1,1]
scalar f6c1 = c1_2[2,1]

matrix col1 = (f1c1 \ f2c1 \ f3c1 \ f4c1 \ f5c1 \ f6c1)
mat li col1


*Column 3
tab intersex [w=factor],  matcell(c1)
scalar f4c3 = c1[1,1]
scalar f1c3 = c1[2,1]

tab sex intersex if intersex==1 [w=factor], matcell(c1_1)
scalar f2c3 = c1_1[1,1]
scalar f3c3 = c1_1[2,1]

tab sex intersex if intersex==0 [w=factor], matcell(c1_2)
scalar f5c3 = c1_2[1,1]
scalar f6c3 = c1_2[2,1]

matrix col3 = (f1c3 \ f2c3 \ f3c3 \ f4c3 \ f5c3 \ f6c3)
mat li col3


*Percents
gen male=1
replace male=0 if sex==1

gen endosex=1 if intersex==0
replace endosex=0 if intersex==1
tab sex

*Column 2
mean(intersex) 
scalar f1c2 = r(table)[1,1]
mean(endosex) 
scalar f4c2 = r(table)[1,1]
mean(male) if intersex==1 
scalar f2c2 = r(table)[1,1]
mean(sex) if intersex==1 
scalar f3c2 = r(table)[1,1]
mean(male) if endosex==1 
scalar f5c2 = r(table)[1,1]
mean(sex) if endosex==1 
scalar f6c2 = r(table)[1,1]

matrix col2 = (f1c2 \ f2c2 \ f3c2 \ f4c2 \ f5c2 \ f6c2)*100

*Column 4
mean(intersex) [w=factor]
scalar f1c4 = r(table)[1,1]
mean(endosex) [w=factor]
scalar f4c4 = r(table)[1,1]
mean(male) [w=factor] if intersex==1 
scalar f2c4 = r(table)[1,1]
mean(sex) [w=factor] if intersex==1 
scalar f3c4 = r(table)[1,1]
mean(male) [w=factor] if endosex==1 
scalar f5c4 = r(table)[1,1]
mean(sex) [w=factor] if endosex==1 
scalar f6c4 = r(table)[1,1]

matrix col4 = (f1c4 \ f2c4 \ f3c4 \ f4c4 \ f5c4 \ f6c4)*100

mat final =[col1, col2, col3, col4]
mat li final

putexcel set "${tables}desc_stat.xlsx", sheet("Sample Size", replace) modify

putexcel B1=("Unweighted") 
putexcel B2=("Observations")
putexcel C2=("Percentage")

putexcel D1 =("Weighted")
putexcel D2=("Observations")
putexcel E2=("Percentage") 

putexcel A3 =("Intersex") 
putexcel A4 =("Male")
putexcel A5 =("Female")
putexcel A6 =("Endosex")
putexcel A7 =("Male")
putexcel A8 =("Female")

putexcel B3=matrix(final), nformat(number_d2)

