/*Figures S1-S3
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

********************************************************
*NO LGBTQI
drop if LGBTQ==1

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}rej_exp_nolgbtq.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}wellbeing_nolgbtq.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}lab_mark_out_nolgbtq.png", replace

*/

/*Figures S4-S6
**************************************************************
*NO WEIGHTS
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people


gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        mean `var' if inter==`j'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}rej_exp_no_weights.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}wellbeing_no_weights.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Endosex Female) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}lab_mark_out_no_weights.png", replace

*/

/*Figures S7-S9
***************************************************************INTERSEX BY SEX
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if sex==1 & intersex==1
replace inter=2 if sex==0 & intersex==1
replace inter=3 if sex==1 & intersex==0
replace inter=4 if sex==0 & intersex==0
label define lab_int 1 "Intersex Female" 2 "Intersex Male" 3 "Endosex Female" 4 "Endosex Male"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"

local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/4 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex Female) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Intersex Male) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Female) msymbol(Dh) msize(small)) ///
		(var1_4 var2_4 var3_4 var4_4 var5_4 var6_4 var7_4, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}rej_exp_sex.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex Female) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Intersex Male) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Female) msymbol(Dh) msize(small)) ///
         (var8_4 var9_4 var10_4 var11_4, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}wellbeing_sex.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex Female) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Intersex Male) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Female) msymbol(Dh) msize(small)) ///
         (var12_4 var13_4 var14_4 var15_4 var16_4, label(Endosex Male) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}lab_mark_out_sex.png", replace
*/

/*
*****Disability Figures S10-S12
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

tab any_disability
svy: tab any_disability 
svy: tab any_disability if intersex==1 
svy: tab any_disability if intersex==0 

gen inter=1 if intersex==1
replace inter=2 if any_disability==1 & intersex==0
replace inter=3 if any_disability==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Disability" 3 "No disability"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(With disability) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Without disability) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}rej_exp_dis.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(With disability) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Without disability) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}wellbeing_dis.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(With disability) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Without disability) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}lab_mark_out_dis.png", replace
*/

/*
******Age group/Birth cohort Figures S13-S15
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

tab age_group
svy: tab age_group

gen inter=1 if intersex==1 & age_group==1
replace inter=2 if intersex==1 & age_group==2
replace inter=3 if intersex==1 & age_group==3

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label("15-29") ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label("30-44") msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label("45-64") msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}rej_exp_age.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label("15-29") ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label("30-44") msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label("45-64") msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}wellbeing_age.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label("15-29") ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label("30-44") msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label("45-64") msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(3))
graph export "${figures}lab_mark_out_age.png", replace
*/


/*
*******************************************************
*LGB+ HETERO Figures S16-S18
**************************************************
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if orientation!=0 & intersex==0
replace inter=3 if orientation==0 & intersex==0
label define lab_int 1 "Intersex" 2 "LGB+" 3 "Heterosexual"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Endosex LGB+) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Heterosexual) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}rej_exp_lgbtq.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Endosex LGB+) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Heterosexual) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}wellbeing_lgbtq.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Endosex LGB+) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Heterosexual) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}lab_mark_out_lgbtq.png", replace
*/

/*
********************************************************
*LGB+ TRANS CIS Figures S19 - S21
***********************************************************
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if identity!=0 & intersex==0
replace inter=3 if identity==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Trans+" 3 "Cisgender"
label values inter lab_int


label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


local k = 1
foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis  mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    forvalues j=1/3 {
        svy, subpop(if inter==`j'): mean `var'
		ereturn list
        estimates store var`k'_`j'
    }
    local k = `=`k'+1'
}

*Figure 1: Rejection experiences
coefplot (var1_1 var2_1 var3_1 var4_1 var5_1 var6_1 var7_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var1_2 var2_2 var3_2 var4_2 var5_2 var6_2 var7_2, label(Endosex Trans+) msymbol(Sh) msize(small)) ///
         (var1_3 var2_3 var3_3 var4_3 var5_3 var6_3 var7_3, label(Endosex Cisgender) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}rej_exp_trans.png", replace

*Figure 2: Wellbeing
coefplot (var8_1 var9_1 var10_1 var11_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var8_2 var9_2 var10_2 var11_2, label(Endosex Trans+) msymbol(Sh) msize(small)) ///
         (var8_3 var9_3 var10_3 var11_3, label(Endosex Cisgender) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}wellbeing_trans.png", replace

*Figure 3: Labor market outcomes		 
coefplot (var12_1 var13_1 var14_1 var15_1 var16_1, label(Intersex) ms(C) mfc(gs16) msize(small)) ///
         (var12_2 var13_2 var14_2 var15_2 var16_2, label(Endosex Trans+) msymbol(Sh) msize(small)) ///
         (var12_3 var13_3 var14_3 var15_3 var16_3, label(Endosex Cisgender) msymbol(Dh) msize(small)), ///
         scheme(s2mono) graphregion(color(white)) legend(col(2))
graph export "${figures}lab_mark_out_trans.png", replace

*/
