************************************
**REGRESSIONS
************************************
*Intersex against endosex male
*Tables S14 S15 S16

use "${procdata}data_base.dta", clear
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)
keep if age >= 15 & age <= 64

gen int_dummy = (intersex == 1) & !missing(intersex)
label define int_dummy 0 "Endosex" 1 "Intersex" 
label values int_dummy int_dummy
gen sex_female = (sex == 1 & intersex == 0) & !missing(intersex)
label define sex_female 0 "Not Endosex Female" 1 "Endosex Female" 
label values sex_female sex_female

* Recode LGBTQI+ identity variables
gen bisexual_dummy = (orientation == 1)
label variable bisexual_dummy Bisexual
gen gay_dummy = (orientation == 2)
label variable gay_dummy Gay
gen other_dummy = (orientation == 3)
label variable other_dummy Other
gen trans_dummy = (identity== 1) 
label variable trans_dummy "Trans+"

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"

forvalues i=1/9{
matrix results_`i' = J(1, 1, .) 
matrix pv_`i' = J(1, 1, .)
}

foreach outcomes in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    *OLS
    qui svy: reg `outcomes' int_dum sex_female
estimates store reg1
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_1 = results_1 \ (`b_1')
	matrix results_1 = results_1 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_1 = pv_1\ (`pv_1')

			
    qui svy: reg `outcomes' int_dum sex_female  age indig afro skin_tone
	estimates store reg2
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_2 = results_2 \ (`b_1')
	matrix results_2 = results_2 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_2 = pv_2\ (`pv_1')

    qui svy: reg `outcomes' int_dum sex_female  age indig afro skin_tone gay_dummy bisexual_dummy other_dummy trans_dummy
	estimates store reg3
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_3 = results_3 \ (`b_1')
	matrix results_3 = results_3 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_3 = pv_3\ (`pv_1')
	
	*LOGISTIC+MARGINS
    qui svy: logistic `outcomes' int_dum sex_female
	estimates store reg4
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_4 = results_4 \ (`b_1')
	matrix results_4 = results_4 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_4 = pv_4\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg5
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_7 = results_7 \ (`b_1')
	matrix results_7 = results_7 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_7 = pv_7\ (`pv_1')

    qui svy: logistic `outcomes' int_dum sex_female  age indig afro skin_tone 
	estimates store reg6
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_5 = results_5 \ (`b_1')
	matrix results_5 = results_5 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_5 = pv_5\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg7
	qui return list	
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_8 = results_8 \ (`b_1')
	matrix results_8 = results_8 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_8 = pv_8\ (`pv_1')
	
    qui svy: logistic `outcomes' int_dum sex_female  age indig afro skin_tone gay_dummy bisexual_dummy other_dummy trans_dummy 
	estimates store reg8
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_6 = results_6 \ (`b_1')
	matrix results_6 = results_6 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_6 = pv_6\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg9
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_9 = results_9 \ (`b_1')
	matrix results_9 = results_9 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_9 = pv_9\ (`pv_1')
}


mat final=[results_1, results_2, results_3, results_4, results_5, results_6, results_7, results_8, results_9]	
mat final=final[2...,.]
mat pv=[pv_1, pv_2, pv_3, pv_4, pv_5, pv_6, pv_7, pv_8, pv_9]	
mat pv=pv[2...,.]

putexcel set "${tables}regs.xlsx", sheet("Rejection", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Childhood stigma")
putexcel A4=("Childhood bullying")
putexcel A6 =("Adolescence stigma")
putexcel A8 =("Adolescence bullying")
putexcel A10 =("Medical attention or medication denied")
putexcel A12 =("Access to public bathrooms denied")
putexcel A14=("Harasment and violence experiences")

*Matrix to excel
putexcel B2=matrix(final[1..14,.]), nformat(number_d2)
putexcel B18=matrix(pv[1..7,.]), nformat(number_d2)

*Wellbeing
putexcel set "${tables}regs.xlsx", sheet("Wellbeing", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Never had a sexual relationship")
putexcel A4=("Life dissatisfaction")
putexcel A6 =("Mental health issues")
putexcel A8 =("Suicidal intention")


*Matrix to excel
putexcel B2=matrix(final[15..22,.]), nformat(number_d2)
putexcel B12=matrix(pv[8..11,.]), nformat(number_d2)

*Labor market
putexcel set "${tables}regs.xlsx", sheet("Labor Market", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Not in labor force")
putexcel A4=("Unemployment")
putexcel A6 =("Work rejection")
putexcel A8 =("Economic wellbeing")
putexcel A10 =("Job satisfaction")


*Matrix to excel
putexcel B2=matrix(final[23..32,.]), nformat(number_d2)
putexcel B16=matrix(pv[12..16,.]), nformat(number_d2)



************************************
**REGRESSIONS
************************************
*Intersex against endosex female
*Tables S17 S18 S19

use "${procdata}data_base.dta", clear
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)
keep if age >= 15 & age <= 64

gen int_dummy = (intersex == 1) & !missing(intersex)
label define int_dummy 0 "Endosex" 1 "Intersex" 
label values int_dummy int_dummy
gen sex_male = (sex == 0 & intersex == 0) & !missing(intersex)
label define sex_male 0 "Not Endosex Male" 1 "Endosex Male" 
label values sex_male sex_female

* Recode LGBTQI+ identity variables
gen bisexual_dummy = (orientation == 1)
label variable bisexual_dummy Bisexual
gen gay_dummy = (orientation == 2)
label variable gay_dummy Gay
gen other_dummy = (orientation == 3)
label variable other_dummy Other
gen trans_dummy = (identity== 1) 
label variable trans_dummy "Trans+"

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"

forvalues i=1/9{
matrix results_`i' = J(1, 1, .) 
matrix pv_`i' = J(1, 1, .)
}

foreach outcomes in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2 {
    *OLS
    qui svy: reg `outcomes' int_dum sex_male
estimates store reg1
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_1 = results_1 \ (`b_1')
	matrix results_1 = results_1 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_1 = pv_1\ (`pv_1')

			
    qui svy: reg `outcomes' int_dum sex_male  age indig afro skin_tone
	estimates store reg2
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_2 = results_2 \ (`b_1')
	matrix results_2 = results_2 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_2 = pv_2\ (`pv_1')

    qui svy: reg `outcomes' int_dum sex_male  age indig afro skin_tone gay_dummy bisexual_dummy other_dummy trans_dummy
	estimates store reg3
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_3 = results_3 \ (`b_1')
	matrix results_3 = results_3 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_3 = pv_3\ (`pv_1')
	
	*LOGISTIC+MARGINS
    qui svy: logistic `outcomes' int_dum sex_male
	estimates store reg4
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_4 = results_4 \ (`b_1')
	matrix results_4 = results_4 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_4 = pv_4\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg5
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_7 = results_7 \ (`b_1')
	matrix results_7 = results_7 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_7 = pv_7\ (`pv_1')

    qui svy: logistic `outcomes' int_dum sex_male  age indig afro skin_tone 
	estimates store reg6
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_5 = results_5 \ (`b_1')
	matrix results_5 = results_5 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_5 = pv_5\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg7
	qui return list	
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_8 = results_8 \ (`b_1')
	matrix results_8 = results_8 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_8 = pv_8\ (`pv_1')
	
    qui svy: logistic `outcomes' int_dum sex_male  age indig afro skin_tone gay_dummy bisexual_dummy other_dummy trans_dummy 
	estimates store reg8
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_6 = results_6 \ (`b_1')
	matrix results_6 = results_6 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_6 = pv_6\ (`pv_1')
	
	qui margins, dydx(int_dummy) post
	estimates store reg9
	qui return list
	local b_1 = r(table)[1,1]
	local se_1 = r(table)[2,1]
	matrix results_9 = results_9 \ (`b_1')
	matrix results_9 = results_9 \ (`se_1')
	local pv_1 = r(table)[4,1]
	matrix pv_9 = pv_9\ (`pv_1')
}


mat final=[results_1, results_2, results_3, results_4, results_5, results_6, results_7, results_8, results_9]	
mat final=final[2...,.]
mat pv=[pv_1, pv_2, pv_3, pv_4, pv_5, pv_6, pv_7, pv_8, pv_9]	
mat pv=pv[2...,.]




putexcel set "${tables}regs.xlsx", sheet("Rejection F", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Childhood stigma")
putexcel A4=("Childhood bullying")
putexcel A6 =("Adolescence stigma")
putexcel A8 =("Adolescence bullying")
putexcel A10 =("Medical attention or medication denied")
putexcel A12 =("Access to public bathrooms denied")
putexcel A14=("Harasment and violence experiences")

*Matrix to excel
putexcel B2=matrix(final[1..14,.]), nformat(number_d2)
putexcel B18=matrix(pv[1..7,.]), nformat(number_d2)

*Wellbeing
putexcel set "${tables}regs.xlsx", sheet("Wellbeing F", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Never had a sexual relationship")
putexcel A4=("Life dissatisfaction")
putexcel A6 =("Mental health issues")
putexcel A8 =("Suicidal intention")


*Matrix to excel
putexcel B2=matrix(final[15..22,.]), nformat(number_d2)
putexcel B12=matrix(pv[8..11,.]), nformat(number_d2)

*Labor market
putexcel set "${tables}regs.xlsx", sheet("Labor Market F", replace) modify
putexcel B1=("OLS 1") 
putexcel C1 =("OLS 2") 
putexcel D1 = ("OLS 3") 
putexcel E1 = ("Logistic 1") 
putexcel F1 = ("Logistic 2") 
putexcel G1 = ("Logistic 3") 
putexcel H1 = ("Margins 1") 
putexcel I1 = ("Margins 2") 
putexcel J1 = ("Margins 3") 

putexcel A2=("Not in labor force")
putexcel A4=("Unemployment")
putexcel A6 =("Work rejection")
putexcel A8 =("Economic wellbeing")
putexcel A10 =("Job satisfaction")


*Matrix to excel
putexcel B2=matrix(final[23..32,.]), nformat(number_d2)
putexcel B16=matrix(pv[12..16,.]), nformat(number_d2)

