use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

*********************************************************
*Table S17
gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int

gen int_fem = 1 if intersex==1 & !missing(intersex)
replace int_fem = 0 if sex==1 & intersex==0 & !missing(intersex)
label define lab_int_f 0 "Endosex Female" 1 "Intersex"  
label values int_fem lab_int_f

gen int_male = 1 if intersex==1 & !missing(intersex)
replace int_male = 0 if sex==0 & intersex==0 & !missing(intersex)
label define lab_intm 0 "Endosex Male" 1 "Intersex" 
label values int_male lab_intm

gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
gen notlfp=1-lfp

* Initialize a matrix to store p-values (21 tests)
matrix pvals_int_fem = J(16, 1, .)
matrix pvals_int_male = J(16, 1, .)


foreach var in int_fem int_male{
    local test_num = 0

    // Regression 1: Childhood Stigma
	qui svy: reg child_rej1 `var' 
	qui test `var' 
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 2: Childhood Bullying
    qui svy: reg child_rej2 `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 3: Adolescence Stigma
    qui svy: reg adol_rej1 `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 4: Adolescence Bullying
    qui svy: reg adol_rej2 `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 5: Medical Attention Denied
    qui svy: reg p11_5_1 `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 6: Bathroom Access Denied
    qui svy: reg bath_access `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
    
    // Regression 7: Harassment and Violence
    qui svy: reg harras `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
	
	qui svy: reg sexual_relation `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)

	qui svy: reg life_dis `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)

	qui svy: reg mental `var' 
    qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
	
	qui svy: reg suic_inten `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)

	qui	svy: reg notlfp  `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)

	qui svy: reg unemp `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)

	qui svy: reg work_rejection `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
	
	qui svy: reg p12_4_1 `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
	
	qui svy: reg p12_4_2 `var' 
	qui test `var'
    local test_num = `test_num' + 1
    matrix pvals_`var'[`test_num', 1] = r(p)
}



* Define the number of tests
local m = 32

* Initialize a new matrix to store adjusted p-values
matrix adj_pvals_int_fem = J(16, 1, .)
matrix adj_pvals_int_male = J(16, 1, .)

* Loop through each p-value, apply Bonferroni correction, and store
foreach var in int_fem int_male {
forvalues i = 1/16 {
    local original_p_`var' = pvals_`var'[`i', 1]
    local adjusted_p_`var' = `original_p_`var'' * `m'
    if (`adjusted_p_`var'' > 1) {
        local adjusted_p_`var' = 1
    }
    matrix adj_pvals_`var'[`i', 1] = `adjusted_p_`var''
}
}

* Display the original and adjusted p-values
mat results = [pvals_int_fem, adj_pvals_int_fem, pvals_int_male, adj_pvals_int_male]
mat colnames results = "Female pvalues" "Female adjusted" "Male pvalues" "Male adjusted"

mat li results, format(%3.2f)

putexcel set "${tables}bonferroni.xlsx", replace
putexcel A1 = matrix(results), names nformat(number_d2)
