*Table S18
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


cap program drop myreg
program myreg, rclass

gen ee1 = runiform() if intersex==0
gen ee2 = runiform() if intersex==1

gen intersex_fp = intersex
replace intersex_fp = 1 if ee1<0.1/60

gen intersex_fn = intersex
replace intersex_fn = 0 if ee2<0.1

// Create corresponding inter variables for simulated datasets
gen inter_fp = 1 if intersex_fp == 1
replace inter_fp = 2 if sex == 1 & intersex_fp == 0
replace inter_fp = 3 if sex == 0 & intersex_fp == 0
label values inter_fp lab_int

gen inter_fn = 1 if intersex_fn == 1
replace inter_fn = 2 if sex == 1 & intersex_fn == 0
replace inter_fn = 3 if sex == 0 & intersex_fn == 0
label values inter_fn lab_int

foreach int in inter inter_fp inter_fn {
	

svy: reg child_rej1 i.`int'
    local b1 = _b[2.`int']
	local b8 = _b[3.`int']
	qui test 2.`int' 
    local pv1 = r(p)
	qui test 3.`int' 
    local pv8 = r(p)

    svy: reg child_rej2 i.`int' 
    local b2 = _b[2.`int']
	local b9 = _b[3.`int']
	qui test 2.`int' 
    local pv2 = r(p)
	qui test 3.`int' 
    local pv9 = r(p)

    svy: reg adol_rej1 i.`int' 
    local b3 = _b[2.`int']
	local b10 = _b[3.`int']
	qui test 2.`int' 
    local pv3 = r(p)
	qui test 3.`int' 
    local pv10 = r(p)

    svy: reg adol_rej2 i.`int' 
    local b4 = _b[2.`int']
	local b11 = _b[3.`int']
	qui test 2.`int' 
    local pv4 = r(p)
	qui test 3.`int' 
    local pv11 = r(p)
	
	svy: reg p11_5_1 i.`int'
    local b5 = _b[2.`int']
	local b12 = _b[3.`int']
	qui test 2.`int' 
    local pv5 = r(p)
	qui test 3.`int' 
    local pv12 = r(p)
	
	svy: reg bath_access i.`int' 
	local b6 = _b[2.`int']
	local b13 = _b[3.`int']
	qui test 2.`int' 
    local pv6 = r(p)
	qui test 3.`int' 
    local pv13 = r(p)
	
	svy: reg harras i.`int' 
    local b7 = _b[2.`int']
	local b14 = _b[3.`int']
	qui test 2.`int' 
    local pv7 = r(p)
	qui test 3.`int' 
    local pv14 = r(p)

 	forvalues i=1/14 {
	    return scalar b`i'_`int' = `b`i''
		return scalar pv`i'_`int' = (`pv`i''<0.05)
	}

	}
		
	drop ee1 ee2 inter_fp inter_fn intersex_fp intersex_fn

end
		
simulate b1 = r(b1_inter_fp) /// 
         pv1 = r(pv1_inter_fp) /// 
         b2 = r(b2_inter_fp) /// 
         pv2 = r(pv2_inter_fp) /// 
         b3 = r(b3_inter_fp) /// 
         pv3 = r(pv3_inter_fp) /// 
         b4 = r(b4_inter_fp) /// 
         pv4 = r(pv4_inter_fp) /// 
         b5 = r(b5_inter_fp) /// 
         pv5 = r(pv5_inter_fp) /// 
         b6 = r(b6_inter_fp) /// 
         pv6 = r(pv6_inter_fp) /// 
         b7 = r(b7_inter_fp) /// 
         pv7 = r(pv7_inter_fp) /// 
         b8 = r(b8_inter_fp) /// 
         pv8 = r(pv8_inter_fp) /// 
         b9 = r(b9_inter_fp) /// 
         pv9 = r(pv9_inter_fp) /// 
         b10 = r(b10_inter_fp) /// 
         pv10 = r(pv10_inter_fp) /// 
         b11 = r(b11_inter_fp) /// 
         pv11 = r(pv11_inter_fp) /// 
         b12 = r(b12_inter_fp) /// 
         pv12 = r(pv12_inter_fp) /// 
         b13 = r(b13_inter_fp) /// 
         pv13 = r(pv13_inter_fp) /// 
         b14 = r(b14_inter_fp) /// 
         pv14 = r(pv14_inter_fp) /// 
         b15 = r(b1_inter_fn) /// 
         pv15 = r(pv1_inter_fn) /// 
         b16 = r(b2_inter_fn) /// 
         pv16 = r(pv2_inter_fn) /// 
         b17 = r(b3_inter_fn) /// 
         pv17 = r(pv3_inter_fn) /// 
         b18 = r(b4_inter_fn) /// 
         pv18 = r(pv4_inter_fn) /// 
         b19 = r(b5_inter_fn) /// 
         pv19 = r(pv5_inter_fn) /// 
         b20 = r(b6_inter_fn) /// 
         pv20 = r(pv6_inter_fn) /// 
         b21 = r(b7_inter_fn) /// 
         pv21 = r(pv7_inter_fn) /// 
         b22 = r(b8_inter_fn) /// 
         pv22 = r(pv8_inter_fn) /// 
         b23 = r(b9_inter_fn) /// 
         pv23 = r(pv9_inter_fn) /// 
         b24 = r(b10_inter_fn) /// 
         pv24 = r(pv10_inter_fn) /// 
         b25 = r(b11_inter_fn) /// 
         pv25 = r(pv11_inter_fn) /// 
         b26 = r(b12_inter_fn) /// 
         pv26 = r(pv12_inter_fn) /// 
         b27 = r(b13_inter_fn) /// 
         pv27 = r(pv13_inter_fn) /// 
         b28 = r(b14_inter_fn) /// 
         pv28 = r(pv14_inter_fn), /// 
         reps(100) /// 
         seed(12) : myreg

g id = _n
reshape long b pv, i(id) j(threshold)

*original
estpost tabstat b pv if threshold<8 , s(mean) by(threshold) 
matrix b1 = e(_b)'
matrix pv1 = e(pv)' 

estpost tabstat b pv if threshold>7 & threshold<15 , s(mean) by(threshold) 
matrix b2 = e(_b)'
matrix pv2 = e(pv)'
*fp
estpost tabstat b pv if threshold>14 & threshold<22 , s(mean) by(threshold) 
matrix b3 = e(_b)'
matrix pv3 = e(pv)' 

estpost tabstat b pv if threshold>21  , s(mean) by(threshold) 
matrix b4 = e(_b)'
matrix pv4 = e(pv)'


matrix pvals = [b1, pv1, b2, pv2, b3, pv3 , b4, pv4]
matrix colnames pvals = "False Positive Female (beta)" "False Positive Female (pv)" "False Positive Male (beta)" "False Positive Male (pv)" "False Negative Female (beta)" "False Negative Female (pv)" "False Negative Male (beta)" "False Negative Male (pv)"
mat li pvals

putexcel set "${tables}fp_fn.xlsx", sheet("fp fn") modify
*10% threshold
putexcel A11 = matrix(pvals), names nformat(number_d2)

**********************************
*30% threshold
*Table S18
*Table S18
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


cap program drop myreg
program myreg, rclass

gen ee1 = runiform() if intersex==0
gen ee2 = runiform() if intersex==1

gen intersex_fp = intersex
replace intersex_fp = 1 if ee1<0.3/60

gen intersex_fn = intersex
replace intersex_fn = 0 if ee2<0.3

// Create corresponding inter variables for simulated datasets
gen inter_fp = 1 if intersex_fp == 1
replace inter_fp = 2 if sex == 1 & intersex_fp == 0
replace inter_fp = 3 if sex == 0 & intersex_fp == 0
label values inter_fp lab_int

gen inter_fn = 1 if intersex_fn == 1
replace inter_fn = 2 if sex == 1 & intersex_fn == 0
replace inter_fn = 3 if sex == 0 & intersex_fn == 0
label values inter_fn lab_int

foreach int in inter inter_fp inter_fn {
	

svy: reg child_rej1 i.`int'
    local b1 = _b[2.`int']
	local b8 = _b[3.`int']
	qui test 2.`int' 
    local pv1 = r(p)
	qui test 3.`int' 
    local pv8 = r(p)

    svy: reg child_rej2 i.`int' 
    local b2 = _b[2.`int']
	local b9 = _b[3.`int']
	qui test 2.`int' 
    local pv2 = r(p)
	qui test 3.`int' 
    local pv9 = r(p)

    svy: reg adol_rej1 i.`int' 
    local b3 = _b[2.`int']
	local b10 = _b[3.`int']
	qui test 2.`int' 
    local pv3 = r(p)
	qui test 3.`int' 
    local pv10 = r(p)

    svy: reg adol_rej2 i.`int' 
    local b4 = _b[2.`int']
	local b11 = _b[3.`int']
	qui test 2.`int' 
    local pv4 = r(p)
	qui test 3.`int' 
    local pv11 = r(p)
	
	svy: reg p11_5_1 i.`int'
    local b5 = _b[2.`int']
	local b12 = _b[3.`int']
	qui test 2.`int' 
    local pv5 = r(p)
	qui test 3.`int' 
    local pv12 = r(p)
	
	svy: reg bath_access i.`int' 
	local b6 = _b[2.`int']
	local b13 = _b[3.`int']
	qui test 2.`int' 
    local pv6 = r(p)
	qui test 3.`int' 
    local pv13 = r(p)
	
	svy: reg harras i.`int' 
    local b7 = _b[2.`int']
	local b14 = _b[3.`int']
	qui test 2.`int' 
    local pv7 = r(p)
	qui test 3.`int' 
    local pv14 = r(p)

 	forvalues i=1/14 {
	    return scalar b`i'_`int' = `b`i''
		return scalar pv`i'_`int' = (`pv`i''<0.05)
	}

	}
		
	drop ee1 ee2 inter_fp inter_fn intersex_fp intersex_fn

end
		
simulate b1 = r(b1_inter_fp) /// 
         pv1 = r(pv1_inter_fp) /// 
         b2 = r(b2_inter_fp) /// 
         pv2 = r(pv2_inter_fp) /// 
         b3 = r(b3_inter_fp) /// 
         pv3 = r(pv3_inter_fp) /// 
         b4 = r(b4_inter_fp) /// 
         pv4 = r(pv4_inter_fp) /// 
         b5 = r(b5_inter_fp) /// 
         pv5 = r(pv5_inter_fp) /// 
         b6 = r(b6_inter_fp) /// 
         pv6 = r(pv6_inter_fp) /// 
         b7 = r(b7_inter_fp) /// 
         pv7 = r(pv7_inter_fp) /// 
         b8 = r(b8_inter_fp) /// 
         pv8 = r(pv8_inter_fp) /// 
         b9 = r(b9_inter_fp) /// 
         pv9 = r(pv9_inter_fp) /// 
         b10 = r(b10_inter_fp) /// 
         pv10 = r(pv10_inter_fp) /// 
         b11 = r(b11_inter_fp) /// 
         pv11 = r(pv11_inter_fp) /// 
         b12 = r(b12_inter_fp) /// 
         pv12 = r(pv12_inter_fp) /// 
         b13 = r(b13_inter_fp) /// 
         pv13 = r(pv13_inter_fp) /// 
         b14 = r(b14_inter_fp) /// 
         pv14 = r(pv14_inter_fp) /// 
         b15 = r(b1_inter_fn) /// 
         pv15 = r(pv1_inter_fn) /// 
         b16 = r(b2_inter_fn) /// 
         pv16 = r(pv2_inter_fn) /// 
         b17 = r(b3_inter_fn) /// 
         pv17 = r(pv3_inter_fn) /// 
         b18 = r(b4_inter_fn) /// 
         pv18 = r(pv4_inter_fn) /// 
         b19 = r(b5_inter_fn) /// 
         pv19 = r(pv5_inter_fn) /// 
         b20 = r(b6_inter_fn) /// 
         pv20 = r(pv6_inter_fn) /// 
         b21 = r(b7_inter_fn) /// 
         pv21 = r(pv7_inter_fn) /// 
         b22 = r(b8_inter_fn) /// 
         pv22 = r(pv8_inter_fn) /// 
         b23 = r(b9_inter_fn) /// 
         pv23 = r(pv9_inter_fn) /// 
         b24 = r(b10_inter_fn) /// 
         pv24 = r(pv10_inter_fn) /// 
         b25 = r(b11_inter_fn) /// 
         pv25 = r(pv11_inter_fn) /// 
         b26 = r(b12_inter_fn) /// 
         pv26 = r(pv12_inter_fn) /// 
         b27 = r(b13_inter_fn) /// 
         pv27 = r(pv13_inter_fn) /// 
         b28 = r(b14_inter_fn) /// 
         pv28 = r(pv14_inter_fn), /// 
         reps(100) /// 
         seed(12) : myreg

g id = _n
reshape long b pv, i(id) j(threshold)

*original
estpost tabstat b pv if threshold<8 , s(mean) by(threshold) 
matrix b1 = e(_b)'
matrix pv1 = e(pv)' 

estpost tabstat b pv if threshold>7 & threshold<15 , s(mean) by(threshold) 
matrix b2 = e(_b)'
matrix pv2 = e(pv)'
*fp
estpost tabstat b pv if threshold>14 & threshold<22 , s(mean) by(threshold) 
matrix b3 = e(_b)'
matrix pv3 = e(pv)' 

estpost tabstat b pv if threshold>21  , s(mean) by(threshold) 
matrix b4 = e(_b)'
matrix pv4 = e(pv)'


matrix pvals = [b1, pv1, b2, pv2, b3, pv3 , b4, pv4]
matrix colnames pvals = "False Positive Female (beta)" "False Positive Female (pv)" "False Positive Male (beta)" "False Positive Male (pv)" "False Negative Female (beta)" "False Negative Female (pv)" "False Negative Male (beta)" "False Negative Male (pv)"
mat li pvals
putexcel set "${tables}fp_fn.xlsx", sheet("fp fn") modify
*30% threshold
putexcel A23 = matrix(pvals), names nformat(number_d2)

****************************************************
*50% threshold
*Table S18
*Table S18
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


cap program drop myreg
program myreg, rclass

gen ee1 = runiform() if intersex==0
gen ee2 = runiform() if intersex==1

gen intersex_fp = intersex
replace intersex_fp = 1 if ee1<0.5/60

gen intersex_fn = intersex
replace intersex_fn = 0 if ee2<0.5

// Create corresponding inter variables for simulated datasets
gen inter_fp = 1 if intersex_fp == 1
replace inter_fp = 2 if sex == 1 & intersex_fp == 0
replace inter_fp = 3 if sex == 0 & intersex_fp == 0
label values inter_fp lab_int

gen inter_fn = 1 if intersex_fn == 1
replace inter_fn = 2 if sex == 1 & intersex_fn == 0
replace inter_fn = 3 if sex == 0 & intersex_fn == 0
label values inter_fn lab_int

foreach int in inter inter_fp inter_fn {
	

svy: reg child_rej1 i.`int'
    local b1 = _b[2.`int']
	local b8 = _b[3.`int']
	qui test 2.`int' 
    local pv1 = r(p)
	qui test 3.`int' 
    local pv8 = r(p)

    svy: reg child_rej2 i.`int' 
    local b2 = _b[2.`int']
	local b9 = _b[3.`int']
	qui test 2.`int' 
    local pv2 = r(p)
	qui test 3.`int' 
    local pv9 = r(p)

    svy: reg adol_rej1 i.`int' 
    local b3 = _b[2.`int']
	local b10 = _b[3.`int']
	qui test 2.`int' 
    local pv3 = r(p)
	qui test 3.`int' 
    local pv10 = r(p)

    svy: reg adol_rej2 i.`int' 
    local b4 = _b[2.`int']
	local b11 = _b[3.`int']
	qui test 2.`int' 
    local pv4 = r(p)
	qui test 3.`int' 
    local pv11 = r(p)
	
	svy: reg p11_5_1 i.`int'
    local b5 = _b[2.`int']
	local b12 = _b[3.`int']
	qui test 2.`int' 
    local pv5 = r(p)
	qui test 3.`int' 
    local pv12 = r(p)
	
	svy: reg bath_access i.`int' 
	local b6 = _b[2.`int']
	local b13 = _b[3.`int']
	qui test 2.`int' 
    local pv6 = r(p)
	qui test 3.`int' 
    local pv13 = r(p)
	
	svy: reg harras i.`int' 
    local b7 = _b[2.`int']
	local b14 = _b[3.`int']
	qui test 2.`int' 
    local pv7 = r(p)
	qui test 3.`int' 
    local pv14 = r(p)

 	forvalues i=1/14 {
	    return scalar b`i'_`int' = `b`i''
		return scalar pv`i'_`int' = (`pv`i''<0.05)
	}

	}
		
	drop ee1 ee2 inter_fp inter_fn intersex_fp intersex_fn

end
		
simulate b1 = r(b1_inter_fp) /// 
         pv1 = r(pv1_inter_fp) /// 
         b2 = r(b2_inter_fp) /// 
         pv2 = r(pv2_inter_fp) /// 
         b3 = r(b3_inter_fp) /// 
         pv3 = r(pv3_inter_fp) /// 
         b4 = r(b4_inter_fp) /// 
         pv4 = r(pv4_inter_fp) /// 
         b5 = r(b5_inter_fp) /// 
         pv5 = r(pv5_inter_fp) /// 
         b6 = r(b6_inter_fp) /// 
         pv6 = r(pv6_inter_fp) /// 
         b7 = r(b7_inter_fp) /// 
         pv7 = r(pv7_inter_fp) /// 
         b8 = r(b8_inter_fp) /// 
         pv8 = r(pv8_inter_fp) /// 
         b9 = r(b9_inter_fp) /// 
         pv9 = r(pv9_inter_fp) /// 
         b10 = r(b10_inter_fp) /// 
         pv10 = r(pv10_inter_fp) /// 
         b11 = r(b11_inter_fp) /// 
         pv11 = r(pv11_inter_fp) /// 
         b12 = r(b12_inter_fp) /// 
         pv12 = r(pv12_inter_fp) /// 
         b13 = r(b13_inter_fp) /// 
         pv13 = r(pv13_inter_fp) /// 
         b14 = r(b14_inter_fp) /// 
         pv14 = r(pv14_inter_fp) /// 
         b15 = r(b1_inter_fn) /// 
         pv15 = r(pv1_inter_fn) /// 
         b16 = r(b2_inter_fn) /// 
         pv16 = r(pv2_inter_fn) /// 
         b17 = r(b3_inter_fn) /// 
         pv17 = r(pv3_inter_fn) /// 
         b18 = r(b4_inter_fn) /// 
         pv18 = r(pv4_inter_fn) /// 
         b19 = r(b5_inter_fn) /// 
         pv19 = r(pv5_inter_fn) /// 
         b20 = r(b6_inter_fn) /// 
         pv20 = r(pv6_inter_fn) /// 
         b21 = r(b7_inter_fn) /// 
         pv21 = r(pv7_inter_fn) /// 
         b22 = r(b8_inter_fn) /// 
         pv22 = r(pv8_inter_fn) /// 
         b23 = r(b9_inter_fn) /// 
         pv23 = r(pv9_inter_fn) /// 
         b24 = r(b10_inter_fn) /// 
         pv24 = r(pv10_inter_fn) /// 
         b25 = r(b11_inter_fn) /// 
         pv25 = r(pv11_inter_fn) /// 
         b26 = r(b12_inter_fn) /// 
         pv26 = r(pv12_inter_fn) /// 
         b27 = r(b13_inter_fn) /// 
         pv27 = r(pv13_inter_fn) /// 
         b28 = r(b14_inter_fn) /// 
         pv28 = r(pv14_inter_fn), /// 
         reps(100) /// 
         seed(12) : myreg

g id = _n
reshape long b pv, i(id) j(threshold)

*original
estpost tabstat b pv if threshold<8 , s(mean) by(threshold) 
matrix b1 = e(_b)'
matrix pv1 = e(pv)' 

estpost tabstat b pv if threshold>7 & threshold<15 , s(mean) by(threshold) 
matrix b2 = e(_b)'
matrix pv2 = e(pv)'
*fp
estpost tabstat b pv if threshold>14 & threshold<22 , s(mean) by(threshold) 
matrix b3 = e(_b)'
matrix pv3 = e(pv)' 

estpost tabstat b pv if threshold>21  , s(mean) by(threshold) 
matrix b4 = e(_b)'
matrix pv4 = e(pv)'


matrix pvals = [b1, pv1, b2, pv2, b3, pv3 , b4, pv4]
matrix colnames pvals = "False Positive Female (beta)" "False Positive Female (pv)" "False Positive Male (beta)" "False Positive Male (pv)" "False Negative Female (beta)" "False Negative Female (pv)" "False Negative Male (beta)" "False Negative Male (pv)"
mat li pvals

putexcel set "${tables}fp_fn.xlsx", sheet("fp fn") modify
*50% threshold
putexcel A34 = matrix(pvals), names nformat(number_d2)

****************************************************
*80% threshold
*Table S18
*Table S18
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


cap program drop myreg
program myreg, rclass

gen ee1 = runiform() if intersex==0
gen ee2 = runiform() if intersex==1

gen intersex_fp = intersex
replace intersex_fp = 1 if ee1<0.8/60

gen intersex_fn = intersex
replace intersex_fn = 0 if ee2<0.8

// Create corresponding inter variables for simulated datasets
gen inter_fp = 1 if intersex_fp == 1
replace inter_fp = 2 if sex == 1 & intersex_fp == 0
replace inter_fp = 3 if sex == 0 & intersex_fp == 0
label values inter_fp lab_int

gen inter_fn = 1 if intersex_fn == 1
replace inter_fn = 2 if sex == 1 & intersex_fn == 0
replace inter_fn = 3 if sex == 0 & intersex_fn == 0
label values inter_fn lab_int

foreach int in inter inter_fp inter_fn {
	

svy: reg child_rej1 i.`int'
    local b1 = _b[2.`int']
	local b8 = _b[3.`int']
	qui test 2.`int' 
    local pv1 = r(p)
	qui test 3.`int' 
    local pv8 = r(p)

    svy: reg child_rej2 i.`int' 
    local b2 = _b[2.`int']
	local b9 = _b[3.`int']
	qui test 2.`int' 
    local pv2 = r(p)
	qui test 3.`int' 
    local pv9 = r(p)

    svy: reg adol_rej1 i.`int' 
    local b3 = _b[2.`int']
	local b10 = _b[3.`int']
	qui test 2.`int' 
    local pv3 = r(p)
	qui test 3.`int' 
    local pv10 = r(p)

    svy: reg adol_rej2 i.`int' 
    local b4 = _b[2.`int']
	local b11 = _b[3.`int']
	qui test 2.`int' 
    local pv4 = r(p)
	qui test 3.`int' 
    local pv11 = r(p)
	
	svy: reg p11_5_1 i.`int'
    local b5 = _b[2.`int']
	local b12 = _b[3.`int']
	qui test 2.`int' 
    local pv5 = r(p)
	qui test 3.`int' 
    local pv12 = r(p)
	
	svy: reg bath_access i.`int' 
	local b6 = _b[2.`int']
	local b13 = _b[3.`int']
	qui test 2.`int' 
    local pv6 = r(p)
	qui test 3.`int' 
    local pv13 = r(p)
	
	svy: reg harras i.`int' 
    local b7 = _b[2.`int']
	local b14 = _b[3.`int']
	qui test 2.`int' 
    local pv7 = r(p)
	qui test 3.`int' 
    local pv14 = r(p)

 	forvalues i=1/14 {
	    return scalar b`i'_`int' = `b`i''
		return scalar pv`i'_`int' = (`pv`i''<0.05)
	}

	}
		
	drop ee1 ee2 inter_fp inter_fn intersex_fp intersex_fn

end
		
simulate b1 = r(b1_inter_fp) /// 
         pv1 = r(pv1_inter_fp) /// 
         b2 = r(b2_inter_fp) /// 
         pv2 = r(pv2_inter_fp) /// 
         b3 = r(b3_inter_fp) /// 
         pv3 = r(pv3_inter_fp) /// 
         b4 = r(b4_inter_fp) /// 
         pv4 = r(pv4_inter_fp) /// 
         b5 = r(b5_inter_fp) /// 
         pv5 = r(pv5_inter_fp) /// 
         b6 = r(b6_inter_fp) /// 
         pv6 = r(pv6_inter_fp) /// 
         b7 = r(b7_inter_fp) /// 
         pv7 = r(pv7_inter_fp) /// 
         b8 = r(b8_inter_fp) /// 
         pv8 = r(pv8_inter_fp) /// 
         b9 = r(b9_inter_fp) /// 
         pv9 = r(pv9_inter_fp) /// 
         b10 = r(b10_inter_fp) /// 
         pv10 = r(pv10_inter_fp) /// 
         b11 = r(b11_inter_fp) /// 
         pv11 = r(pv11_inter_fp) /// 
         b12 = r(b12_inter_fp) /// 
         pv12 = r(pv12_inter_fp) /// 
         b13 = r(b13_inter_fp) /// 
         pv13 = r(pv13_inter_fp) /// 
         b14 = r(b14_inter_fp) /// 
         pv14 = r(pv14_inter_fp) /// 
         b15 = r(b1_inter_fn) /// 
         pv15 = r(pv1_inter_fn) /// 
         b16 = r(b2_inter_fn) /// 
         pv16 = r(pv2_inter_fn) /// 
         b17 = r(b3_inter_fn) /// 
         pv17 = r(pv3_inter_fn) /// 
         b18 = r(b4_inter_fn) /// 
         pv18 = r(pv4_inter_fn) /// 
         b19 = r(b5_inter_fn) /// 
         pv19 = r(pv5_inter_fn) /// 
         b20 = r(b6_inter_fn) /// 
         pv20 = r(pv6_inter_fn) /// 
         b21 = r(b7_inter_fn) /// 
         pv21 = r(pv7_inter_fn) /// 
         b22 = r(b8_inter_fn) /// 
         pv22 = r(pv8_inter_fn) /// 
         b23 = r(b9_inter_fn) /// 
         pv23 = r(pv9_inter_fn) /// 
         b24 = r(b10_inter_fn) /// 
         pv24 = r(pv10_inter_fn) /// 
         b25 = r(b11_inter_fn) /// 
         pv25 = r(pv11_inter_fn) /// 
         b26 = r(b12_inter_fn) /// 
         pv26 = r(pv12_inter_fn) /// 
         b27 = r(b13_inter_fn) /// 
         pv27 = r(pv13_inter_fn) /// 
         b28 = r(b14_inter_fn) /// 
         pv28 = r(pv14_inter_fn), /// 
         reps(100) /// 
         seed(12) : myreg

g id = _n
reshape long b pv, i(id) j(threshold)

*original
estpost tabstat b pv if threshold<8 , s(mean) by(threshold) 
matrix b1 = e(_b)'
matrix pv1 = e(pv)' 

estpost tabstat b pv if threshold>7 & threshold<15 , s(mean) by(threshold) 
matrix b2 = e(_b)'
matrix pv2 = e(pv)'
*fp
estpost tabstat b pv if threshold>14 & threshold<22 , s(mean) by(threshold) 
matrix b3 = e(_b)'
matrix pv3 = e(pv)' 

estpost tabstat b pv if threshold>21  , s(mean) by(threshold) 
matrix b4 = e(_b)'
matrix pv4 = e(pv)'


matrix pvals = [b1, pv1, b2, pv2, b3, pv3 , b4, pv4]
matrix colnames pvals = "False Positive Female (beta)" "False Positive Female (pv)" "False Positive Male (beta)" "False Positive Male (pv)" "False Negative Female (beta)" "False Negative Female (pv)" "False Negative Male (beta)" "False Negative Male (pv)"
mat li pvals

putexcel set "${tables}fp_fn.xlsx", sheet("fp fn") modify
*80% threshold
putexcel A45 = matrix(pvals), names nformat(number_d2)




*********
*ORIGINAL
*********
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


cap program drop myreg
program myreg, rclass

foreach int in inter  {
	
	svy: reg child_rej1 i.`int'
    local b1 = _b[2.`int']
	local b8 = _b[3.`int']
	qui test 2.`int' 
    local pv1 = r(p)
	qui test 3.`int' 
    local pv8 = r(p)

    svy: reg child_rej2 i.`int' 
    local b2 = _b[2.`int']
	local b9 = _b[3.`int']
	qui test 2.`int' 
    local pv2 = r(p)
	qui test 3.`int' 
    local pv9 = r(p)

    svy: reg adol_rej1 i.`int' 
    local b3 = _b[2.`int']
	local b10 = _b[3.`int']
	qui test 2.`int' 
    local pv3 = r(p)
	qui test 3.`int' 
    local pv10 = r(p)

    svy: reg adol_rej2 i.`int' 
    local b4 = _b[2.`int']
	local b11 = _b[3.`int']
	qui test 2.`int' 
    local pv4 = r(p)
	qui test 3.`int' 
    local pv11 = r(p)
	
	svy: reg p11_5_1 i.`int'
    local b5 = _b[2.`int']
	local b12 = _b[3.`int']
	qui test 2.`int' 
    local pv5 = r(p)
	qui test 3.`int' 
    local pv12 = r(p)
	
	svy: reg bath_access i.`int' 
	local b6 = _b[2.`int']
	local b13 = _b[3.`int']
	qui test 2.`int' 
    local pv6 = r(p)
	qui test 3.`int' 
    local pv13 = r(p)
	
	svy: reg harras i.`int' 
    local b7 = _b[2.`int']
	local b14 = _b[3.`int']
	qui test 2.`int' 
    local pv7 = r(p)
	qui test 3.`int' 
    local pv14 = r(p)

 	forvalues i=1/14 {
	    return scalar b`i'_`int' = `b`i''
		return scalar pv`i'_`int' = `pv`i''
	}

	
	
	}	
end
		
simulate b1 = r(b1_inter) /// 
         pv1 = r(pv1_inter) /// 
         b2 = r(b2_inter) /// 
         pv2 = r(pv2_inter) /// 
         b3 = r(b3_inter) /// 
         pv3 = r(pv3_inter) /// 
         b4 = r(b4_inter) /// 
         pv4 = r(pv4_inter) /// 
         b5 = r(b5_inter) /// 
         pv5 = r(pv5_inter) /// 
         b6 = r(b6_inter) /// 
         pv6 = r(pv6_inter) /// 
         b7 = r(b7_inter) /// 
         pv7 = r(pv7_inter) /// 
         b8 = r(b8_inter) /// 
         pv8 = r(pv8_inter) /// 
		 b9 = r(b9_inter) /// 
         pv9 = r(pv9_inter) /// 
	     b10 = r(b10_inter) /// 
         pv10 = r(pv10_inter) /// 
         b11 = r(b11_inter) /// 
         pv11 = r(pv11_inter) /// 		 
         b12 = r(b12_inter) /// 
         pv12 = r(pv12_inter) /// 		 
         b13 = r(b13_inter) /// 
         pv13 = r(pv13_inter) /// 		 
         b14 = r(b14_inter) /// 
         pv14 = r(pv14_inter) , /// 
         reps(1) /// 
         seed(12) : myreg

g id = _n
reshape long b pv, i(id) j(threshold)

*Female 
estpost tabstat b pv if threshold<=7  , s(mean) by(threshold) 
matrix b1 = e(_b)'
matrix pv1 = e(pv)' 
*Male 
estpost tabstat b pv if threshold>7 , s(mean) by(threshold) 
matrix b2 = e(_b)'
matrix pv2 = e(pv)'


matrix pvals = [b1, pv1, b2, pv2]
matrix colnames pvals = "Original Female (beta)" "Original Female (pv)" "Original Male (beta)" "Original Male (pv)" 
mat li pvals, format(%9.2f)

putexcel set "${tables}fp_fn.xlsx", sheet("fp fn") modify
*original
putexcel A1 = matrix(pvals), names nformat(number_d2)