*Table S2, S6 and S10
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int

label variable child_rej1 "Childhood stigma"
label variable child_rej2 "Childhood bullying"
label variable adol_rej1 "Adolescence stigma"
label variable adol_rej2 "Adolescence bullying"
label variable p11_5_1 "Medical attention or medication denied"
label variable bath_access "Access to public bathrooms denied"
label variable harras "Harassment and violence experiences"
gen life_dis = p12_4_6
recode life_dis (1=0) (0=1)
label variable sexual_relation "Never had a sexual relationship"
label variable life_dis "Life dissatisfaction"
label variable mental "Mental health issues"
label variable suic_inten "Suicidal intention"
gen notlfp=1-lfp
label variable notlfp "Not in labor force"
label variable unemp "Unemployment"
label variable work_rejection "Work rejection"
label variable p12_4_1 "Economic wellbeing"
label variable p12_4_2 "Job satisfaction"


matrix results = J(1, 8, .) 

foreach var in child_rej1 child_rej2 adol_rej1 adol_rej2 p11_5_1 bath_access harras sexual_relation life_dis mental suic_inten notlfp unemp work_rejection p12_4_1 p12_4_2{
    svy: logistic `var' i.inter  
	return list
	mat li r(table)
    *estimates store `var'_`j'
	local beta_f = r(table)[1,2]
    local lower_f = r(table)[5,2]
    local upper_f = r(table)[6,2]
	local p_f = r(table)[4,2] 
	local beta_m = r(table)[1,3]
    local lower_m = r(table)[5,3]
    local upper_m = r(table)[6,3]
    local se_f = r(table)[2,2]
    local se_m = r(table)[2,3]
	local p_m = r(table)[4,3] 

    matrix results = results \ (`beta_f', `p_f', `lower_f', `upper_f', `beta_m', `p_m', `lower_m', `upper_m')
    matrix results = results \ (`se_f', ., ., ., `se_m', ., ., .)
    }

mat li results, format(%9.2f)

******************
*EXCEL
*******************
putexcel set "${tables}logistic.xlsx", sheet("Rejection", replace) modify
putexcel B1=("Odd ratios") 
putexcel C1 =("P-value") 
putexcel D1 =("Lower") 
putexcel E1 = ("Upper") 
putexcel F1 = ("Odd ratios") 
putexcel G1 =("P-value") 
putexcel H1 = ("Lower") 
putexcel I1 = ("Upper") 


putexcel A2 =("Childhood_stigma") 
putexcel A4 =("Childhood_bullying")
putexcel A6 =("Adolescence stigma")
putexcel A8 =("Adolescence bullying")
putexcel A10 =("Medical attention or medication denied")
putexcel A12 =("Access to public bathrooms denied")
putexcel A14 =("Harassment and violence experiences")

*Matrix to excel - Table S2
putexcel B1=matrix(results[1..15,.]), nformat(number_d2)

putexcel set "${tables}logistic.xlsx", sheet("Wellbeing", replace) modify
putexcel B1=("Odd ratios") 
putexcel C1 =("P-value") 
putexcel D1 =("Lower") 
putexcel E1 = ("Upper") 
putexcel F1 = ("Odd ratios") 
putexcel G1 =("P-value") 
putexcel H1 = ("Lower") 
putexcel I1 = ("Upper") 


putexcel A2 =("Never had a sexual relationship") 
putexcel A4 =("Life dissatisfaction")
putexcel A6 =("Mental health issues")
putexcel A8 =("Suicidal intention")

*Matrix to excel- Table S6
putexcel B2=matrix(results[16..23,.]), nformat(number_d2)

putexcel set "${tables}logistic.xlsx", sheet("Labor Market", replace) modify
putexcel B1=("Odd ratios") 
putexcel C1 =("P-value") 
putexcel D1 =("Lower") 
putexcel E1 = ("Upper") 
putexcel F1 = ("Odd ratios") 
putexcel G1 =("P-value") 
putexcel H1 = ("Lower") 
putexcel I1 = ("Upper") 

putexcel A2 =("Not in labor force") 
putexcel A4 =("Unemployment")
putexcel A6 =("Work rejection")
putexcel A8 =("Economic wellbeing")
putexcel A10 =("Job satisfaction")

*Matrix to excel - Table S10
putexcel B2=matrix(results[24..33,.]), nformat(number_d2)
