*********************************************************
************TABLES (S3, S4, S5, S7, S9, S11, S13)
*********************************************************
use "${procdata}data_base.dta", clear
keep if age>=15 & age<=64 //working age people
svyset upm_dis [pweight = factor], strata(est_dis) singleunit(centered)

gen inter=1 if intersex==1
replace inter=2 if sex==1 & intersex==0
replace inter=3 if sex==0 & intersex==0
label define lab_int 1 "Intersex" 2 "Endosex Female" 3 "Endosex Male"
label values inter lab_int


matrix results_i = J(1, 1, .) 
matrix results_f = J(1, 1, .) 
matrix results_m = J(1, 1, .)
matrix results_0 = J(1, 1, .) 
matrix results_1 = J(1, 1, .)


foreach var in child_rej1 p5_3_1 p5_3_2 p5_3_3 p5_3_4 child_rej2 p5_4_1 p5_4_2 p5_4_3 p5_4_4 p5_4_5 adol_rej1 p6_10_1 p6_10_2 p6_10_3 p6_10_4 adol_rej2 p6_11_1 p6_11_2 p6_11_3 p6_11_4 p6_11_5 p11_5_1 bath_access harras p11_1_1 p11_1_2 p11_1_3 p11_1_4 p11_1_5 p11_1_6 sexual_enc sexual_relation mental p10_1_1 p10_1_2 p10_1_3 p10_1_4 p10_1_5 suic_idea suic_inten p10_4_1 p10_4_2 p10_4_3 p10_4_4 p10_4_5 p10_4_6 p10_4_7 p10_4_8 lfp unemp work_rejection p11_4_1 p11_4_2 p11_4_3 p11_4_4 p11_4_5 p12_4_1 p12_4_2 p12_4_3 p12_4_4 p12_4_5 p12_4_6 p12_5_1 p12_5_2 p12_5_3 p12_5_4 p12_5_5 p12_5_6 p12_5_7 {
    forvalue j=1/3{
		qui svy: mean `var' if inter==`j'
		qui estat sd
		qui return list
			if `j'==1 {
				local b_i = r(mean)[1,1]
				local se_i = r(sd)[1,1]
				matrix results_i = results_i \ (`b_i')
				matrix results_i = results_i \ (`se_i')
				}
			if `j'==2 {
				local b_f = r(mean)[1,1]
				local se_f = r(sd)[1,1] 
				matrix results_f = results_f \ (`b_f')
				matrix results_f = results_f \ (`se_f')
				}
			if `j'==3{
				local b_m = r(mean)[1,1]
				local se_m = r(sd)[1,1] 
				matrix results_m = results_m \ (`b_m')
				matrix results_m = results_m \ (`se_m')
				}	
			}
		
		forvalue i=0/1{
		qui svy: mean `var' if sex==`i' | intersex==1, over(intersex) coeflegend
		matrix results_`i' = results_`i' \_b[c.`var' @1.intersex] - _b[c.`var' @0bn.intersex]

		qui test _b[c.`var'@0bn.intersex]	= _b[c.`var'@1.intersex]
		qui return list
		scalar p_val = r(p) // Store the p-value
		matrix results_`i' = results_`i' \ p_val
	}
}			


mat final=[results_f, results_m, results_i, results_1, results_0]
mat final=final[2...,.]
mat li final, format(%9.2f)


*******************
*Childhood
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Childhood", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2=("Childhood stigma")
putexcel A4 =("your way of dressing or grooming?" ) 
putexcel A6 =("your tastes or interests?")
putexcel A8 =("your way of speaking or expressing yourself?")
putexcel A10 =("your manners or way of behaving?")
putexcel A12=("Childhood bullying")
putexcel A14 =("reject or exclude you from social activities?")
putexcel A16 =("insult you, mock you, or say things that offended you?")
putexcel A18 =("steal, hide, or break your belongings?")
putexcel A20 =("threaten or blackmail you?")
putexcel A22 =("push, pull, or hit you?")
putexcel A24 =("Observations")

*Matrix to excel
putexcel B2=matrix(final[1..22,.]), nformat(number_d2)

*******************
*Adolescence
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Adolescence", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Adolescence stigma")
putexcel A4 =("your way of dressing or grooming?" ) 
putexcel A6 =("your tastes or interests?")
putexcel A8 =("your way of speaking or expressing yourself?")
putexcel A10 =("your manners or way of behaving?")
putexcel A12 =("Adolescence bullying")
putexcel A14 =("reject or exclude you from social activities?")
putexcel A16 =("insult you, mock you, or say things that offended you?")
putexcel A18 =("steal, hide, or break your belongings?")
putexcel A20 =("threaten or blackmail you?")
putexcel A22 =("push, pull, or hit you?")
putexcel A24 =("Observations")

*Matrix to excel
putexcel B2=matrix(final[23..44,.]), nformat(number_d2)

*******************
*Harasment
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Harasment", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Have you been unjustifiably denied medical attention or medication?")
putexcel A4 =("Have you been unjustifiably denied access to public bathrooms?")
putexcel A6=("Harasment and violence experiences")
putexcel A8 =("Have you been threatened or sexually assaulted?")
putexcel A10 =("Have you been bothered by someone making sexual propositions in exchange for payment?")
putexcel A12 =("Have you been forced to have sexual relations?")
putexcel A14 =("Have you been humiliated, embarrassed, or verbally abused?")
putexcel A16 =("Have you received offensive messages?")
putexcel A18 =("Have you been touched or groped without your consent?")
putexcel A20 =("Observations")

*Matrix to excel
putexcel B2=matrix(final[45..62,.]), nformat(number_d2)

*******************
*Well being
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Well-being", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("People who have never had their first meeting with someone where there was kissing or cuddling and they agreed" ) 
putexcel A4 =("People who have never had their first sexual relationship")
putexcel A6 =("Mental Health") 
putexcel A8 =("insomnia")
putexcel A10 =("stress")
putexcel A12 =("depression")
putexcel A14 =("loss or increase in appetite or weigh")
putexcel A16 =("anguish, fear or anxiety?")
putexcel A18 =("Observations")

putexcel B2=matrix(final[63..78,.]), nformat(number_d2)

*******************
*Suicidal
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Suicidal", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Suicidal Ideation")
putexcel A4 =("Suicidal Intention")
putexcel A6 =("financial problems")
putexcel A8 =("family or relationship problems")
putexcel A10 =("health problems")
putexcel A12 =("problems at school")
putexcel A14 =("problems at work")
putexcel A16 =("problems because of your orientation")
putexcel A18 =("problems due to your gender")
putexcel A20 =("other")
putexcel A22 =("Observations")

putexcel B2=matrix(final[79..98,.]), nformat(number_d2)

*******************
*Labor Market
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Labor market", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Labor force participation")
putexcel A4 =("Unemployment")
putexcel A6 =("Workplace rejection")
putexcel A8 =("Did you receive offensive comments or teasing?")
putexcel A10 =("Were you excluded from events or social activities?")
putexcel A12 =("Were you bothered or harassed?")
putexcel A14 =("Did you receive unequal treatment regarding benefits, labor benefits, or promotions?")
putexcel A16 =("Were you hit, assaulted, or threatened?")
putexcel A18 =("Observations")

putexcel B2=matrix(final[99..114,.]), nformat(number_d2)

*******************
*Satisfaction
*******************
putexcel set "${tables}desc_stat.xlsx", sheet("Satisfaction", replace) modify
putexcel A1 =("Category")
putexcel B1=("Endosex female") 
putexcel C1 =("Endosex male") 
putexcel D1 = ("Intersex") 
putexcel E1 = ("(3)-(1)") 
putexcel F1 = ("(3)-(2)") 

putexcel A2 =("Economic situation?")
putexcel A4 =("Job situation?")
putexcel A6 =("Family relationship?")
putexcel A8 =("Physical appearance?")
putexcel A10 =("Personality?")
putexcel A12 =("Life in general?")
putexcel A14 =("What I do in my life is worthwhile")
putexcel A16 =("I have a purpose or mission in life")
putexcel A18 =("I feel good about myself")
putexcel A20 =("I am a fortunate person")
putexcel A22 =("I am free to decide my own life")
putexcel A24 =("I am very satisfied with my life")
putexcel A26 =("So far, I have achieved the things that are important to me")
putexcel A28 =("Observations")

putexcel B2=matrix(final[115..140,.]), nformat(number_d2)
